import { ErrorNotification, ErrorNotificationPosition, ErrorNotificationType } from '../types';
/**
 * NotificationBuilder to build ErrorNotification
 * @public
 */
export declare class NotificationBuilder {
    private position;
    private autoClose;
    private closeTimeout;
    private type;
    /**
     * Add position to notification
     * @public
     * @param position - {@link ErrorNotificationPosition}
     * @returns
     */
    withPosition(position: ErrorNotificationPosition): NotificationBuilder;
    /**
     * Add auto close to notification
     * @public
     * @param autoClose - boolean
     * @returns
     */
    withAutoClose(autoClose: boolean): NotificationBuilder;
    /**
     * Add close timeout to notification
     * @public
     * @param closeTimeout - number
     * @returns
     */
    withCloseTimeout(closeTimeout: number): NotificationBuilder;
    /**
     * Add type to notification, if the type is anything other than 'warning' or 'success' do not add it
     * @public
     * @param type - {@link ErrorNotificationType}
     * @returns
     */
    withType(type: ErrorNotificationType): NotificationBuilder;
    /**
     * Build notification
     * @returns ErrorNotification
     */
    build(): ErrorNotification;
}
/**
 * Get notification builder instance
 * @public
 */
export declare const getNotificationBuilder: () => NotificationBuilder;
//# sourceMappingURL=notification-builder.d.ts.map